/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "TextEvent.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomDOMWindow.h"
#include "gdom/GdomTextEvent.h"
#include "gdom/GdomUIEvent.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomDOMWindow.h"
#include "gdom/PrivateGdomTextEvent.h"
#include "gdom/PrivateGdomUIEvent.h"
#include "gdom/PrivateIntGdomDOMWindow.h"
#include "gdom/PrivateIntGdomTextEvent.h"
#include "glib-object.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMTextEvent::GDOMTextEvent(PassRefPtr<WebCore::TextEvent> impl)
    : GDOMUIEvent(impl)
{
}

void
gdom_text_event_init_text_event (GdomTextEvent *thiz, gchar * type_arg, gboolean can_bubble_arg, gboolean cancelable_arg, GdomDOMWindow * view_arg, gchar * data_arg)
{
    g_return_if_fail (thiz);
    WebCore::TextEvent * item = (gdom_text_event_get_private(thiz));
    g_return_if_fail (item);
    g_return_if_fail (type_arg);
    g_return_if_fail (view_arg);
    g_return_if_fail (data_arg);
    WebCore::String _g_type_arg = WebCore::String::fromUTF8(type_arg);
    WebCore::DOMWindow * _g_view_arg = (gdom_dom_window_get_private(view_arg));
    g_return_if_fail (_g_view_arg);
    WebCore::String _g_data_arg = WebCore::String::fromUTF8(data_arg);
    item->initTextEvent(_g_type_arg, can_bubble_arg, cancelable_arg, _g_view_arg, _g_data_arg);

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "TextEvent.h"
#include <gdom/GdomTextEvent.h>
#include <gdom/PrivateGdomTextEvent.h>
#include <gdom/PrivateIntGdomTextEvent.h>
#include <gdom/GdomTextEventprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomTextEvent, gdom_text_event, GDOM_TYPE_UI_EVENT);

/*
struct _GdomTextEventPrivate {
    class WebCore::TextEvent *item;
};

#define GDOM_TEXT_EVENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_TEXT_EVENT, GdomTextEventPrivate))
*/
G_END_DECLS
WebCore::TextEvent *
gdom_text_event_get_private(GdomTextEvent *request)
{
    GDOMTextEvent *res;
    res = static_cast<GDOMTextEvent*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::TextEvent*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_DATA,
};


static void gdom_text_event_finalize(GObject* object)
{
    /*GdomTextEvent* request = GDOM_TEXT_EVENT(object);*/
    /*GdomTextEventPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_UI_EVENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_text_event_parent_class)->finalize(object);
}

static void gdom_text_event__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomTextEvent *self = GDOM_TEXT_EVENT(object);
    WebCore::TextEvent * gself = (gdom_text_event_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_text_event__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomTextEvent *self = GDOM_TEXT_EVENT(object);
    WebCore::TextEvent * gself = (gdom_text_event_get_private(self));
    switch (prop_id) {
    case PROP_DATA:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->data()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_text_event_class_init(GdomTextEventClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_text_event_finalize;
    g_klass->set_property = gdom_text_event__set_property_fn;
    g_klass->get_property = gdom_text_event__get_property_fn;

    g_object_class_install_property (g_klass, PROP_DATA,
            g_param_spec_string ("data", /* name */
                "text_event_data", /* short description */
                "read-only  gchar * TextEvent.data", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomTextEventPrivate));*/
}

static void gdom_text_event_init(GdomTextEvent* request)
{
    /*GdomTextEventPrivate* priv = GDOM_TEXT_EVENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

